netapp_ontap.models.volume_constituents API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.volume_constituents`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class VolumeConstituentsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the VolumeConstituents object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `aggregates: VolumeConstituentsAggregates GET POST PATCH`

    The aggregates field of the volume_constituents.

  `movement: VolumeConstituentsMovement GET POST PATCH`

    Volume movement. All attributes are modify, that is, not writable through POST. Set PATCH state to destination_aggregate to initiate a volume move operation.

  `name: str GET`

    FlexGroup volume constituent name.

  `node: VolumeConstituentsNode GET POST PATCH`

    The node field of the volume_constituents.

  `space: VolumeConstituentsSpace GET POST PATCH`

    The space field of the volume_constituents.